Module output

Module output 

Structs

GameProcess
A running game process whose stdout/stderr are being piped to an OutputFn.
OutputLine
One line of game output, with its source stream.

Enums

OutputKind
Which stream a line came from.

Functions

no_output

Type Aliases

OutputFn
Output callback. Arc so it can be cloned into the two reader tasks (stdout / stderr) and outlive the caller’s stack frame.