pub struct FtbVersionManifest {
pub id: u64,
pub name: String,
pub targets: Vec<FtbTarget>,
pub files: Vec<FtbFile>,
}Expand description
Installation manifest. name is the version name, not the pack name.
Fields
id: u64name: Stringtargets: Vec<FtbTarget>files: Vec<FtbFile>Implementations
Sourceimpl FtbVersionManifest
impl FtbVersionManifest
Sourcepub fn info(&self, pack_name: &str) -> Result<ModpackInfo>
pub fn info(&self, pack_name: &str) -> Result<ModpackInfo>
Describe the Minecraft version and loader, using the separate pack name.