ModrinthClient

Struct ModrinthClient 

pub struct ModrinthClient { /* private fields */ }

Implementations

Source

impl ModrinthClient

pub fn new() -> Self

Source

impl ModrinthClient

pub async fn search_mod( &self, name: &str, loader: &ModLoader, ) -> Result<Vec<MrProject>>

Search for mods.

pub async fn get_project_versions( &self, id: &str, mc_version: &str, loader: &ModLoader, ) -> Result<Vec<MrVersion>>

Versions of a project matching the given MC version and loader. id may be a project ID or slug.

pub async fn get_latest_version( &self, id: &str, mc_version: &str, loader: &ModLoader, ) -> Result<Option<MrVersion>>

Newest version (by publish date) matching the MC version and loader.

pub async fn get_version_by_hash(&self, sha1: &str) -> Result<Option<MrVersion>>

Identify a locally installed file by its SHA1. Returns None if Modrinth doesn’t know the hash.

pub async fn get_latest_by_hash( &self, sha1: &str, mc_version: &str, loader: &ModLoader, ) -> Result<Option<MrVersion>>

Latest version for a file identified by its SHA1, constrained to the given MC version and loader. Returns None if the hash is unknown to Modrinth.