Modrinth modpacks (.mrpack).
A zip holding modrinth.index.json plus overrides/ and client-overrides/.
Spec: https://support.modrinth.com/en/articles/8802351-modrinth-modpack-format-mrpack
Structs
Enums
Constants
Functions
- install_
mrpack - Install a
.mrpackintoinstance/{instance_name}. - install_
mrpack_ files - Extract overrides and download client files without installing Minecraft or its loader.
No Java is required and
instance_config.jsonis not created. Use the returnedModpackInfoto install Minecraft and the loader before the first launch. - read_
mrpack_ index - Read a
.mrpack’s index without installing it.